var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule, Component } from "@angular/core";
import { QueryList, ContentChildren, ElementRef } from "@angular/core";
import { Input, ChangeDetectionStrategy, ChangeDetectorRef } from "@angular/core";
import { CommonModule } from "@angular/common";
import { trigger, state, style, transition, animate } from '@angular/core';
export let CarouselItem = class CarouselItem {
    constructor(_change, element) {
        this._change = _change;
        this.id = 0;
        this._state = "void";
        this.element = element.nativeElement;
    }
    get state() {
        return this._state;
    }
    set state(val) {
        this._state = val;
        setTimeout(() => {
            this._change.markForCheck();
        }, 1);
    }
    get isActive() { return this.state == "in"; }
    getTotalHeight() {
        var height = this.element.clientHeight;
        if (height > 1)
            return height;
        var child = this.element.firstElementChild;
        while (child != null) {
            height += child.offsetHeight;
            child = child.nextElementSibling;
        }
        return height;
    }
};
CarouselItem = __decorate([
    Component({
        selector: ".carousel-item",
        changeDetection: ChangeDetectionStrategy.OnPush,
        template: `
        <div [@slide]="state" class="item-content">
            <ng-content></ng-content>
        </div>
    `,
        animations: [
            trigger("slide", [
                state("right", style({
                    transform: "translate(100%,0)"
                })),
                state("in, void", style({
                    transform: "translate(0,0)"
                })),
                state("left", style({
                    transform: "translate(-100%, 0)"
                })),
                transition("right <=> in", [
                    animate("300ms ease")
                ]),
                transition("left <=> in", [
                    animate("300ms ease")
                ])
            ])
        ]
    }), 
    __metadata('design:paramtypes', [ChangeDetectorRef, ElementRef])
], CarouselItem);
export let Carousel = class Carousel {
    constructor(_change, element) {
        this._change = _change;
        this.hammerInitialized = false;
        this.items = [];
        this._activeIndex = 0;
        this._intervalRef = null;
        this.innerHeight = 0;
        this.panDirection = 0; // 1 left -1 right
        this.lastPanOffset = 0;
        this.element = element.nativeElement;
    }
    get activeIndex() { return this._activeIndex; }
    set activeIndex(val) {
        if (this.items.length == 0) {
            this._activeIndex = -1;
            return;
        }
        this._activeIndex = val;
        for (let i in this.items) {
            let itemIndex = parseInt(i);
            if (i == val.toString())
                this.items[i].state = "in";
            else if (itemIndex == this.getRelativeIndex(-1))
                this.items[i].state = "left";
            else if (itemIndex == this.getRelativeIndex(1))
                this.items[i].state = "right";
            else
                this.items[i].state = "right";
        }
    }
    set interval(val) {
        if (this._intervalRef != null) {
            clearInterval(this._intervalRef);
            this._intervalRef = null;
        }
        if (val > 0)
            setInterval(() => { this.next(); }, val);
    }
    ngAfterContentInit() {
        this.itemQuery.changes.subscribe(() => this.registerItems());
        this.registerItems();
    }
    ngAfterContentChecked() {
        this.updateInnerHeight();
    }
    ngAfterViewInit() {
        if (!this.hammerInitialized && typeof Hammer !== "undefined") {
            var hammer = new Hammer(this.element);
            hammer.on('swiperight', (ev) => {
                this.prev();
            });
            hammer.on('swipeleft', (ev) => {
                this.next();
            });
            /*hammer.on('pan', (ev) => {
                this.pan(ev);
            });
            hammer.on('panleft', (ev) => {
                this.panleft(ev);
            });
            hammer.on('panright', (ev) => {
                this.panright(ev);
            });*/
            this.hammerInitialized = true;
        }
    }
    ngOnDestroy() {
        if (this._intervalRef != null) {
            clearInterval(this._intervalRef);
            this._intervalRef = null;
        }
    }
    registerItems() {
        this.items = [];
        if (this.itemQuery.length == 0)
            return;
        let itemArray = this.itemQuery.toArray();
        for (let i in itemArray)
            itemArray[i].id = i;
        this.items = this.itemQuery.toArray();
        this.activeIndex =
            this.items.reduce((prev, current, index) => {
                if (prev != -1 && current.isActive || !current.isActive) {
                    return prev;
                }
                else
                    return index;
            }, -1);
        if (this.activeIndex == -1)
            this.activeIndex = 0;
        this.updateInnerHeight();
    }
    updateInnerHeight() {
        this.innerHeight = this.items[this.activeIndex].getTotalHeight();
        if (this.innerHeight < 1)
            this.innerHeight = 250;
        this._change.markForCheck();
    }
    getRelativeItem(rel) {
        if (this.items.length == 1)
            return this.items[0];
        return this.items[this.getRelativeIndex(rel)];
    }
    getRelativeIndex(rel) {
        let target = this.activeIndex + rel;
        if (this.items.length == 0)
            return null;
        if (target < 0)
            target = this.items.length - 1;
        else if (target > (this.items.length - 1))
            target = 0;
        return target;
    }
    navigateTo(item) {
        var index = this.items.indexOf(item);
        if (index > this.activeIndex)
            this.next(item);
        else
            this.prev(item);
    }
    prev(item = null) {
        if (this.items.length < 2)
            return;
        this.activeIndex = this.getRelativeIndex(-1);
        this._change.markForCheck();
    }
    next(item = null) {
        if (this.items.length < 2)
            return;
        this.activeIndex = this.getRelativeIndex(1);
        this._change.markForCheck();
    }
    swipeleft() {
        if (this.panDirection == 0)
            this.next();
    }
    swiperight() {
        if (this.panDirection == 0)
            this.prev();
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Number), 
    __metadata('design:paramtypes', [Number])
], Carousel.prototype, "interval", null);
__decorate([
    ContentChildren(CarouselItem), 
    __metadata('design:type', QueryList)
], Carousel.prototype, "itemQuery", void 0);
Carousel = __decorate([
    Component({
        selector: "carousel",
        template: "\n      <div class=\"carousel slide\" >\n        <!--(swiperight)=\"prev()\" (swipeleft)=\"next()\"-->\n        <!--(pan)=\"pan($event)\" (panleft)=\"panleft($event)\" (panright)=\"panright($event)\"\n        (panend)=\"panend($event)\"-->\n        <ol class=\"carousel-indicators\">\n          <!--<li *ngFor=\"let image of images\"\n            (click)=\"switchTo(image)\" [class.active]=\"image.isActive && !image.checkIfAnimating()\">\n            </li> -->\n            <li *ngFor=\"let item of items\"\n              [class.active]=\"item.isActive\"\n              (click)=\"navigateTo(item)\">\n            </li>\n        </ol>\n        <div class=\"carousel-inner\" role=\"listbox\"\n          [style.height.px]=\"innerHeight\">\n            <ng-content select=\"carousel-item,.carousel-item\"></ng-content>\n        </div>\n        <a class=\"left carousel-control\" role=\"button\" (click)=\"prev()\">\n          <span class=\"icon-prev\" aria-hidden=\"true\"></span>\n          <span class=\"sr-only\">Previous</span>\n        </a>\n        <a class=\"right carousel-control\" role=\"button\" (click)=\"next()\">\n          <span class=\"icon-next\" aria-hidden=\"true\"></span>\n          <span class=\"sr-only\">Next</span>\n        </a>\n      </div>\n    ",
        directives: [CarouselItem],
        changeDetection: ChangeDetectionStrategy.OnPush
    }), 
    __metadata('design:paramtypes', [ChangeDetectorRef, ElementRef])
], Carousel);
const carouselDirectives = [Carousel, CarouselItem];
export let FuiCarouselModule = class FuiCarouselModule {
};
FuiCarouselModule = __decorate([
    NgModule({
        imports: [CommonModule],
        declarations: carouselDirectives,
        exports: carouselDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiCarouselModule);
