var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule, Directive, Component, ElementRef, Input, Output, EventEmitter, ContentChildren, QueryList } from '@angular/core';
import { ElementUtils } from "../../utilities/utilities";
export let ScrollItem = class ScrollItem {
    constructor(element) {
        this.element = element.nativeElement;
    }
    get height() {
        return ElementUtils.outerHeight(this.element);
    }
    ngAfterViewInit() {
        this.element = this.element.firstElementChild;
    }
};
ScrollItem = __decorate([
    Directive({
        selector: "[scroll-item],.scroll-item"
    }), 
    __metadata('design:paramtypes', [ElementRef])
], ScrollItem);
export let InfiniteScroller = class InfiniteScroller {
    //test
    constructor(element) {
        this.distance = 100;
        this.height = 'auto';
        this.hideScrollbar = false;
        this.next = new EventEmitter();
        this.prev = new EventEmitter();
        this.topIndexChange = new EventEmitter();
        this.topIndex = 0;
        this.bottomIndexChange = new EventEmitter();
        this.bottomIndex = 0;
        this.lastScroll = 0;
        this.container = element.nativeElement;
    }
    ngAfterContentInit() {
        this.firstItem = this.itemQuery.first;
        this.itemQuery.changes.subscribe(() => {
            this.handleItemChanges();
        });
    }
    ngAfterViewInit() {
        this.container = this.container.querySelector(".scroll-container");
        this.container.scrollTop += 1;
    }
    handleItemChanges() {
        if (this.firstItem == null)
            this.firstItem = this.itemQuery.first;
        if (this.firstItem !== this.itemQuery.first) {
            this.container.scrollTop += this.itemQuery.first.height;
            this.firstItem = this.itemQuery.first;
        }
    }
    getVisableIndicies() {
        var itemArray = this.itemQuery.toArray();
        var visableIndicies = itemArray
            .filter(i => this.checkVisableItem(i))
            .map(i => itemArray.indexOf(i));
        if (visableIndicies.length > 1) {
            this.topIndex = visableIndicies[0];
            this.bottomIndex = visableIndicies[visableIndicies.length - 1];
            this.topIndexChange.next(this.topIndex);
            this.bottomIndexChange.next(this.bottomIndex);
        }
        else if (visableIndicies.length > 0) {
            this.topIndex = visableIndicies[0];
            this.topIndexChange.next(this.topIndex);
        }
    }
    checkVisableItem(item) {
        var itemTop = item.element.offsetTop;
        var itemBottom = itemTop + ElementUtils.outerHeight(item.element);
        var viewTop = this.container.scrollTop + this.container.offsetTop;
        var viewBottom = viewTop + this.container.clientHeight;
        if (itemTop > viewTop && itemTop < viewBottom)
            return true;
        if (itemBottom > viewTop && itemBottom < viewBottom)
            return true;
        if (itemTop < viewTop && itemBottom > viewBottom)
            return true;
        return false;
    }
    doscroll(event) {
        var target = (typeof event.srcElement === 'undefined' ? event.target : event.srcElement);
        var targetRect = target.getBoundingClientRect();
        var bottomPosition = target.scrollHeight - (target.scrollTop + targetRect.height);
        var scrollDown = target.scrollTop > this.lastScroll;
        var saveLastScroll = this.lastScroll;
        this.lastScroll = target.scrollTop;
        if (scrollDown && target.scrollHeight - (target.scrollTop + targetRect.height) <= this.distance * 2) {
            this.next.emit(null);
            if (target.scrollHeight - target.scrollTop === target.clientHeight) {
                target.scrollTop -= 10;
            }
        }
        else if (!scrollDown && target.scrollTop <= this.distance * 2) {
            this.prev.emit(null);
        }
        this.getVisableIndicies();
        if (target.scrollTop < 1)
            target.scrollTop = 1;
    }
    scrollTo(position, animate = true) {
        if (animate)
            ElementUtils.scrollTo(this.container, position, 400);
        else
            this.container.scrollTop = position;
    }
    scrollToIndex(index, animate = true) {
        var itemArray = this.itemQuery.toArray();
        var targetIndex = 0;
        if (index > 0 && index < itemArray.length)
            targetIndex = index;
        else if (index >= itemArray.length)
            targetIndex = itemArray.length - 1;
        if (targetIndex < 0)
            targetIndex = 0;
        var target = this.itemQuery.toArray()[targetIndex];
        var targetPos = target.element.offsetTop - this.container.offsetTop;
        this.scrollTo(targetPos, animate);
    }
    isTop() {
        return this.lastScroll <= 1;
    }
    isBottom() {
        return (this.lastScroll + this.container.clientHeight) >= this.container.scrollHeight - 10;
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Number)
], InfiniteScroller.prototype, "distance", void 0);
__decorate([
    Input(), 
    __metadata('design:type', String)
], InfiniteScroller.prototype, "height", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Boolean)
], InfiniteScroller.prototype, "hideScrollbar", void 0);
__decorate([
    Output(), 
    __metadata('design:type', EventEmitter)
], InfiniteScroller.prototype, "next", void 0);
__decorate([
    Output(), 
    __metadata('design:type', EventEmitter)
], InfiniteScroller.prototype, "prev", void 0);
__decorate([
    Output(), 
    __metadata('design:type', EventEmitter)
], InfiniteScroller.prototype, "topIndexChange", void 0);
__decorate([
    Output(), 
    __metadata('design:type', EventEmitter)
], InfiniteScroller.prototype, "bottomIndexChange", void 0);
__decorate([
    ContentChildren(ScrollItem), 
    __metadata('design:type', QueryList)
], InfiniteScroller.prototype, "itemQuery", void 0);
InfiniteScroller = __decorate([
    Component({
        selector: "infinite-scroller",
        template: `
        <div class="scroll-outer" [class.hide-scrollbar]="hideScrollbar">
            <div class="scroll-container"
                (scroll)="doscroll($event)"
                [style.height]="height">
                <ng-content></ng-content>
            </div>
        </div>
    `,
        styles: [`
        .scroll-container {
            overflow-y: scroll;
            overflow-x: hidden;
            max-height: 100%;
        }

        .scroll-outer.hide-scrollbar .scroll-container {
            margin-right: -16px;
        }

        .scroll-content {
            overflow: auto;
        }
    `]
    }), 
    __metadata('design:paramtypes', [ElementRef])
], InfiniteScroller);
const infiniteScrollerDirectives = [
    InfiniteScroller,
    ScrollItem
];
export let FuiInfiniteScrollerModule = class FuiInfiniteScrollerModule {
};
FuiInfiniteScrollerModule = __decorate([
    NgModule({
        imports: [],
        declarations: infiniteScrollerDirectives,
        exports: infiniteScrollerDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiInfiniteScrollerModule);
